Package: lda
Type: Package
Title: Collapsed Gibbs Sampling Methods for Topic Models
Version: 1.5.2
Date: 2024-04-25
Author: Jonathan Chang
Maintainer: Santiago Olivella <olivella@unc.edu>
Description: Implements latent Dirichlet allocation (LDA)
	     and related models.  This includes (but is not limited
	     to) sLDA, corrLDA, and the mixed-membership stochastic
	     blockmodel.  Inference for all of these models is
	     implemented via a fast collapsed Gibbs sampler written
	     in C.  Utility functions for reading/writing data
	     typically used in topic models, as well as tools for
	     examining posterior distributions are also included.
License: LGPL (>= 2.1)
LazyLoad: yes
Imports: methods (>= 4.3.0)
Suggests: Matrix, reshape2, ggplot2 (>= 3.4.4), penalized, nnet
Depends: R (>= 4.3.0)
NeedsCompilation: yes
Packaged: 2024-04-26 21:30:14 UTC; olivella
Repository: CRAN
Date/Publication: 2024-04-27 23:00:10 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 18:17:32 UTC; unix
Archs: lda.so.dSYM
